==> chat-uikit-react-native-0.0.1.tgz: package/components/Message/MessageContent/MessageContent.tsx <==
import React from 'react';
import {
  View,
  StyleSheet,
} from 'react-native';

import TUIChatEngine, { IMessageModel } from '@tencentcloud/chat-uikit-engine';

import { TextElement } from '../TextElement';
import { FaceElement } from '../FaceElement';
import { ImageElement } from '../ImageElement';
import { VideoElement } from '../VideoElement';
import { FileElement } from '../FileElement';
import { VoiceElement } from '../VoiceElement';
import { CustomElement as DefaultCustomElement, type ICustomElementProps } from '../CustomElement';
import { MergeElement } from '../MergeElement';
import { MessageStatus } from '../MessageStatus';

import { useChatContext } from '../../../context';
import { isIOS } from '../../../utils';


interface IMessageContentProps {
  message: IMessageModel;
  isJoinedMessage: boolean;
  CustomElement?: React.ComponentType<ICustomElementProps>,
}

export const MessageContent = (props: IMessageContentProps) => {
  const { CustomElement: _CustomElement } = useChatContext();
  const {
    message,
    isJoinedMessage,
    CustomElement = _CustomElement || DefaultCustomElement,
  } = props;

  const isImageAndVideo = message.type === TUIChatEngine.TYPES.MSG_IMAGE || message.type === TUIChatEngine.TYPES.MSG_VIDEO;

  const computeMessageContentStyle = () => {
    let style: any = styles.messageContent;
    if (isIOS && message.type === TUIChatEngine.TYPES.MSG_TEXT) {
      style = StyleSheet.flatten([style, {minWidth: 120}]);
    }
    if (message.type === TUIChatEngine.TYPES.MSG_FACE || isImageAndVideo) {
      style = StyleSheet.flatten([style, styles.messageContentColumn]);
    }
    if (message.flow === 'in') {
      style = StyleSheet.flatten([style, styles.messageContentIn]);
      if (isJoinedMessage) {
        style = StyleSheet.flatten([style, styles.messageContentInJoined]);
      }
    } else {
      style = StyleSheet.flatten([style, styles.messageContentOut]);
      if (isJoinedMessage) {
        style = StyleSheet.flatten([style, styles.messageContentOutJoined]);
      }
    }
    return style;
  };

  return (
    <View style={computeMessageContentStyle()}>
      {message.type === TUIChatEngine.TYPES.MSG_TEXT && (
        <TextElement data={message.getMessageContent()} />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_FACE && (
        <FaceElement data={message.getMessageContent()} />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_IMAGE && (
        <ImageElement
          data={message.getMessageContent()}
          flow={message.flow}
          isJoinedMessage={isJoinedMessage}
        />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_VIDEO && (
        <VideoElement
          data={message.getMessageContent()}
          flow={message.flow}
          isJoinedMessage={isJoinedMessage}
        />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_FILE && (
        <FileElement data={message.getMessageContent()} />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_AUDIO && (
        <VoiceElement data={'[Voice]'} />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_CUSTOM && (
        <CustomElement data={'[Custom Message]'} />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_MERGER && (
        <MergeElement data={'[Chat History]'} />
      )}
      <MessageStatus message={message} />
    </View>
  );
};

const styles = StyleSheet.create({
  messageContent: {
    flexShrink: 1,
    flexDirection: 'row',
    alignItems: 'center',
    flexWrap: 'wrap',
    justifyContent: 'flex-start',
    borderColor: '#ECEBEB',
    borderWidth: 0.5,
    borderRadius: 16,
    minHeight: 33,
  },
  messageContentColumn: {
    flexDirection: 'column',
  },
  messageContentIn: {
    borderBottomLeftRadius: 0,
    marginLeft: 4,
  },
  messageContentInJoined: {
    borderBottomLeftRadius: 16,
    marginLeft: 36,
  },
  messageContentOut: {
    borderWidth: 0,
    borderBottomRightRadius: 0,
    backgroundColor: '#F2F7FF',
  },
  messageContentOutJoined: {
    borderBottomRightRadius: 16,
  },
});

==> chat-uikit-react-native-0.0.3.tgz: package/components/Message/MessageContent/MessageContent.tsx <==
import React from 'react';
import {
  View,
  StyleSheet,
} from 'react-native';

import TUIChatEngine, { IMessageModel } from '@tencentcloud/chat-uikit-engine';

import { TextElement } from '../TextElement';
import { FaceElement } from '../FaceElement';
import { ImageElement } from '../ImageElement';
import { VideoElement } from '../VideoElement';
import { FileElement } from '../FileElement';
import { VoiceElement } from '../VoiceElement';
import { CustomElement as DefaultCustomElement, type ICustomElementProps } from '../CustomElement';
import { MergeElement } from '../MergeElement';
import { MessageStatus } from '../MessageStatus';

import { useChatContext } from '../../../context';
import { isIOS } from '../../../utils';

interface IMessageContentProps {
  message: IMessageModel;
  isJoinedMessage: boolean;
  CustomElement?: React.ComponentType<ICustomElementProps>;
}

export const MessageContent = (props: IMessageContentProps) => {
  const { CustomElement: _CustomElement } = useChatContext();
  const {
    message,
    isJoinedMessage,
    CustomElement = _CustomElement || DefaultCustomElement,
  } = props;

  const isImageAndVideo = message.type === TUIChatEngine.TYPES.MSG_IMAGE || message.type === TUIChatEngine.TYPES.MSG_VIDEO;

  const computeMessageContentStyle = () => {
    let style: any = styles.messageContent;
    if (isIOS && message.type === TUIChatEngine.TYPES.MSG_TEXT) {
      style = StyleSheet.flatten([style, { minWidth: 120 }]);
    }
    if (message.type === TUIChatEngine.TYPES.MSG_FACE || isImageAndVideo) {
      style = StyleSheet.flatten([style, styles.messageContentColumn]);
    }
    if (message.flow === 'in') {
      style = StyleSheet.flatten([style, styles.messageContentIn]);
      if (isJoinedMessage) {
        style = StyleSheet.flatten([style, styles.messageContentInJoined]);
      }
    } else {
      style = StyleSheet.flatten([style, styles.messageContentOut]);
      if (isJoinedMessage) {
        style = StyleSheet.flatten([style, styles.messageContentOutJoined]);
      }
    }
    return style;
  };

  return (
    <View style={computeMessageContentStyle()}>
      {message.type === TUIChatEngine.TYPES.MSG_TEXT && (
        <TextElement data={message.getMessageContent()} />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_FACE && (
        <FaceElement data={message.getMessageContent()} />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_IMAGE && (
        <ImageElement
          data={message.getMessageContent()}
          flow={message.flow}
          isJoinedMessage={isJoinedMessage}
        />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_VIDEO && (
        <VideoElement
          data={message.getMessageContent()}
          flow={message.flow}
          isJoinedMessage={isJoinedMessage}
        />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_FILE && (
        <FileElement data={message.getMessageContent()} />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_AUDIO && (
        <VoiceElement data="[Voice]" />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_CUSTOM && (
        <CustomElement data="[Custom Message]" />
      )}
      {message.type === TUIChatEngine.TYPES.MSG_MERGER && (
        <MergeElement data="[Chat History]" />
      )}
      <MessageStatus message={message} />
    </View>
  );
};

const styles = StyleSheet.create({
  messageContent: {
    flexShrink: 1,
    flexDirection: 'row',
    alignItems: 'center',
    flexWrap: 'wrap',
    justifyContent: 'flex-start',
    borderColor: '#ECEBEB',
    borderWidth: 0.5,
    borderRadius: 16,
    minHeight: 33,
  },
  messageContentColumn: {
    flexDirection: 'column',
  },
  messageContentIn: {
    borderBottomLeftRadius: 0,
    marginLeft: 4,
  },
  messageContentInJoined: {
    borderBottomLeftRadius: 16,
    marginLeft: 36,
  },
  messageContentOut: {
    borderWidth: 0,
    borderBottomRightRadius: 0,
    backgroundColor: '#F2F7FF',
  },
  messageContentOutJoined: {
    borderBottomRightRadius: 16,
  },
});
